BeautyOptions class

Image enhancement options.

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lighteningContrastLevel → LighteningContrastLevel?
The contrast level, used with the lighteningLevel parameter. The larger the value, the greater the contrast between light and dark. See LighteningContrastLevel.
final
lighteningLevel → double?
The brightening level, in the range 0.0,1.0, where 0.0 means the original brightening. The default value is 0.0. The higher the value, the greater the degree of brightening.
final
rednessLevel → double?
The redness level, in the range 0.0,1.0, where 0.0 means the original redness. The default value is 0.0. The larger the value, the greater the redness level.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharpnessLevel → double?
The sharpness level, in the range 0.0,1.0, where 0.0 means the original sharpness. The default value is 0.0. The larger the value, the greater the sharpness level.
final
smoothnessLevel → double?
The smoothness level, in the range 0.0,1.0, where 0.0 means the original smoothness. The default value is 0.0. The greater the value, the greater the smoothness level.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited