ChannelMediaInfo class

Channel media information.

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

channelName → String?
The channel name.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String?
The token that enables the user to join the channel.
final
uid → int?
The user ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited