LowlightEnhanceOptions class

The low-light enhancement options.

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode → int
The hash code for this object.
no setterinherited
level → LowLightEnhanceLevel?
The low-light enhancement level. See LowLightEnhanceLevel.
final
mode → LowLightEnhanceMode?
The low-light enhancement mode. See LowLightEnhanceMode.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited