registerPlayerSourceObserver abstract method
Registers a media player observer.
observerThe player observer, listening for events during the playback. See MediaPlayerSourceObserver.
Returns When the method call succeeds, there is no return value; when fails, the AgoraRtcException exception is thrown. You need to catch the exception and handle it accordingly.
Implementation
void registerPlayerSourceObserver(MediaPlayerSourceObserver observer);