PlayerPlaybackStats class

The information of the media file being played.

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

audioBitrateInKbps → int?
The bitrate (kbps) of the audio.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalBitrateInKbps → int?
The total bitrate (kbps) of the media stream.
final
videoBitrateInKbps → int?
The bitrate (kbps) of the video.
final
videoFps → int?
The frame rate (fps) of the video.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited