RtcEngineEx class abstract

This interface class contains multi-channel methods.

Inherited from RtcEngine.

Implemented types
Available extensions

Constructors

RtcEngineEx()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addVideoWatermark({required String watermarkUrl, required WatermarkOptions options}) → Future<void>
Adds a watermark image to the local video.
inherited
addVideoWatermarkEx({required String watermarkUrl, required WatermarkOptions options, required RtcConnection connection}) → Future<void>
Adds a watermark image to the local video.
adjustAudioMixingPlayoutVolume(int volume) → Future<void>
Adjusts the volume of audio mixing for local playback.
inherited
adjustAudioMixingPublishVolume(int volume) → Future<void>
Adjusts the volume of audio mixing for publishing.
inherited
adjustAudioMixingVolume(int volume) → Future<void>
Adjusts the volume during audio mixing.
inherited
adjustCustomAudioPlayoutVolume({required int trackId, required int volume}) → Future<void>
Adjusts the volume of the custom audio track played locally.
inherited
adjustCustomAudioPublishVolume({required int trackId, required int volume}) → Future<void>
Adjusts the volume of the custom audio track played remotely.
inherited
adjustLoopbackSignalVolume(int volume) → Future<void>
Adjusts the volume of the signal captured by the sound card.
inherited
adjustPlaybackSignalVolume(int volume) → Future<void>
Adjusts the playback signal volume of all remote users.
inherited
adjustRecordingSignalVolume(int volume) → Future<void>
Adjusts the capturing signal volume.
inherited
adjustUserPlaybackSignalVolume({required int uid, required int volume}) → Future<void>
Adjusts the playback signal volume of a specified remote user.
inherited
adjustUserPlaybackSignalVolumeEx({required int uid, required int volume, required RtcConnection connection}) → Future<void>
Adjusts the playback signal volume of a specified remote user.
clearVideoWatermarkEx(RtcConnection connection) → Future<void>
Removes the watermark image from the video stream.
clearVideoWatermarks() → Future<void>
Removes the watermark image from the video stream.
inherited
complain({required String callId, required String description}) → Future<void>
Allows a user to complain about the call quality after a call ends.
inherited
configRhythmPlayer(AgoraRhythmPlayerConfig config) → Future<void>
Configures the virtual metronome.
inherited
createCustomVideoTrack() → Future<int>
Creates a custom video track.
inherited
createDataStream(DataStreamConfig config) → Future<int>
Creates a data stream.
inherited
createDataStreamEx({required DataStreamConfig config, required RtcConnection connection}) → Future<int>
Creates a data stream.
createMediaPlayer() → Future<MediaPlayer?>
Creates a media player object.
inherited
destroyCustomVideoTrack(int videoTrackId) → Future<void>
Destroys the specified video track.
inherited
destroyMediaPlayer(MediaPlayer mediaPlayer) → Future<void>
Destroys the media player instance.
inherited
disableAudio() → Future<void>
Disables the audio module.
inherited
disableAudioSpectrumMonitor() → Future<void>
Disables audio spectrum monitoring.
inherited
disableVideo() → Future<void>
Disables the video module.
inherited
enableAudio() → Future<void>
Enables the audio module.
inherited
enableAudioSpectrumMonitor({int intervalInMS = 100}) → Future<void>
Turns on audio spectrum monitoring.
inherited
enableAudioVolumeIndication({required int interval, required int smooth, required bool reportVad}) → Future<void>
Enables the reporting of users' volume indication.
inherited
enableAudioVolumeIndicationEx({required int interval, required int smooth, required bool reportVad, required RtcConnection connection}) → Future<void>
Enables the reporting of users' volume indication.
enableCameraCenterStage(bool enabled) → Future<void>
Enables or disables portrait center stage.
inherited
enableContentInspect({required bool enabled, required ContentInspectConfig config}) → Future<void>
Enables or disables video screenshot and upload.
inherited
enableContentInspectEx({required bool enabled, required ContentInspectConfig config, required RtcConnection connection}) → Future<void>
Enables or disables video screenshot and upload.
enableCustomAudioLocalPlayback({required int trackId, required bool enabled}) → Future<void>
Sets whether to enable the local playback of external audio source.
inherited
enableDualStreamMode({required bool enabled, SimulcastStreamConfig? streamConfig}) → Future<void>
Sets the dual-stream mode on the sender side and the low-quality video stream.
inherited
enableDualStreamModeEx({required bool enabled, required SimulcastStreamConfig streamConfig, required RtcConnection connection}) → Future<void>
Enables or disables dual-stream mode on the sender side.
enableEncryption({required bool enabled, required EncryptionConfig config}) → Future<void>
Enables or disables the built-in encryption.
inherited
enableEncryptionEx({required RtcConnection connection, required bool enabled, required EncryptionConfig config}) → Future<void>
Enables or disables the built-in encryption.
enableExtension({required String provider, required String extension, bool enable = true, MediaSourceType type = MediaSourceType.unknownMediaSource}) → Future<void>
Enables or disables extensions.
inherited
enableFaceDetection(bool enabled) → Future<void>
Enables or disables face detection for the local user.
inherited
enableInEarMonitoring({required bool enabled, required EarMonitoringFilterType includeAudioFilters}) → Future<void>
Enables in-ear monitoring.
inherited
enableInstantMediaRendering() → Future<void>
Enables audio and video frame instant rendering.
inherited
enableLocalAudio(bool enabled) → Future<void>
Enables or disables the local audio capture.
inherited
enableLocalVideo(bool enabled) → Future<void>
Enables/Disables the local video capture.
inherited
enableLoopbackRecording({required bool enabled, String? deviceName}) → Future<void>
Enables loopback audio capturing.
inherited
enableLoopbackRecordingEx({required RtcConnection connection, required bool enabled, String? deviceName}) → Future<void>
Enables loopback audio capturing.
enableMultiCamera({required bool enabled, required CameraCapturerConfiguration config}) → Future<void>
Enables or disables multi-camera capture.
inherited
enableSoundPositionIndication(bool enabled) → Future<void>
Enables or disables stereo panning for remote users.
inherited
enableSpatialAudio(bool enabled) → Future<void>
Enables or disables the spatial audio effect.
inherited
enableVideo() → Future<void>
Enables the video module.
inherited
enableVideoImageSource({required bool enable, required ImageTrackOptions options}) → Future<void>
Sets whether to replace the current video feeds with images when publishing video streams.
inherited
enableVirtualBackground({required bool enabled, required VirtualBackgroundSource backgroundSource, required SegmentationProperty segproperty, MediaSourceType type = MediaSourceType.primaryCameraSource}) → Future<void>
Enables/Disables the virtual background.
inherited
enableVoiceAITuner({required bool enabled, required VoiceAiTunerType type}) → Future<void>
Enables or disables the voice AI tuner.
inherited
enableWebSdkInteroperability(bool enabled) → Future<void>
Enables interoperability with the Agora Web SDK (applicable only in the live streaming scenarios).
inherited
getAudioDeviceInfo() → Future<DeviceInfo>
Gets the audio device information.
inherited
getAudioDeviceManager() → AudioDeviceManager
Gets the AudioDeviceManager object to manage audio devices.
inherited
getAudioMixingCurrentPosition() → Future<int>
Retrieves the playback position (ms) of the music file.
inherited
getAudioMixingDuration() → Future<int>
Retrieves the duration (ms) of the music file.
inherited
getAudioMixingPlayoutVolume() → Future<int>
Retrieves the audio mixing volume for local playback.
inherited
getAudioMixingPublishVolume() → Future<int>
Retrieves the audio mixing volume for publishing.
inherited
getAudioTrackCount() → Future<int>
Gets the index of audio tracks of the current music file.
inherited
getCallIdEx(RtcConnection connection) → Future<String>
Gets the call ID with the connection ID.
getCameraMaxZoomFactor() → Future<double>
Gets the maximum zoom ratio supported by the camera.
inherited
getConnectionState() → Future<ConnectionStateType>
Gets the current connection state of the SDK.
inherited
getConnectionStateEx(RtcConnection connection) → Future<ConnectionStateType>
Gets the current connection state of the SDK.
getCurrentMonotonicTimeInMs() → Future<int>
Gets the current Monotonic Time of the SDK.
inherited
getEffectCurrentPosition(int soundId) → Future<int>
Retrieves the playback position of the audio effect file.
inherited
getEffectDuration(String filePath) → Future<int>
Retrieves the duration of the audio effect file.
inherited
getEffectsVolume() → Future<int>
Retrieves the volume of the audio effects.
inherited
getErrorDescription(int code) → Future<String>
Gets the warning or error description.
inherited
getExtensionProperty({required String provider, required String extension, required String key, required int bufLen, MediaSourceType type = MediaSourceType.unknownMediaSource}) → Future<String>
Gets detailed information on the extensions.
inherited
getLocalSpatialAudioEngine() → LocalSpatialAudioEngine
Gets one LocalSpatialAudioEngine object.
inherited
getMediaEngine() → MediaEngine
Gets one MediaEngine object.
inherited
getMusicContentCenter() → MusicContentCenter
Gets MusicContentCenter.
inherited
getNativeHandle() → Future<int>
Gets the C++ handle of the Native SDK.
inherited
getNetworkType() → Future<int>
Gets the type of the local network connection.
inherited
getNtpWallTimeInMs() → Future<int>
Gets the current NTP (Network Time Protocol) time.
inherited
getScreenCaptureSources({required SIZE thumbSize, required SIZE iconSize, required bool includeScreen}) → Future<List<ScreenCaptureSourceInfo>>
Gets a list of shareable screens and windows.
inherited
getUserInfoByUid(int uid) → Future<UserInfo>
Gets the user information by passing in the user ID.
inherited
getUserInfoByUserAccount(String userAccount) → Future<UserInfo>
Gets the user information by passing in the user account.
inherited
getVersion() → Future<SDKBuildInfo>
Gets the SDK version.
inherited
getVideoDeviceManager() → VideoDeviceManager
Gets the VideoDeviceManager object to manage video devices.
inherited
getVolumeOfEffect(int soundId) → Future<int>
Gets the volume of a specified audio effect file.
inherited
initialize(RtcEngineContext context) → Future<void>
Initializes RtcEngine.
inherited
isCameraAutoExposureFaceModeSupported() → Future<bool>
Checks whether the device supports auto exposure.
inherited
isCameraAutoFocusFaceModeSupported() → Future<bool>
Checks whether the device supports the face auto-focus function.
inherited
isCameraCenterStageSupported() → Future<bool>
Check if the camera supports portrait center stage.
inherited
isCameraExposurePositionSupported() → Future<bool>
Checks whether the device supports manual exposure.
inherited
isCameraExposureSupported() → Future<bool>
Queries whether the current camera supports adjusting exposure value.
inherited
isCameraFaceDetectSupported() → Future<bool>
Checks whether the device camera supports face detection.
inherited
isCameraFocusSupported() → Future<bool>
Check whether the device supports the manual focus function.
inherited
isCameraTorchSupported() → Future<bool>
Checks whether the device supports camera flash.
inherited
isCameraZoomSupported() → Future<bool>
Checks whether the device supports camera zoom.
inherited
isFeatureAvailableOnDevice(FeatureType type) → Future<bool>
Checks whether the device supports the specified advanced feature.
inherited
isSpeakerphoneEnabled() → Future<bool>
Checks whether the speakerphone is enabled.
inherited
joinChannel({required String token, required String channelId, required int uid, required ChannelMediaOptions options}) → Future<void>
Joins a channel with media options.
inherited
joinChannelEx({required String token, required RtcConnection connection, required ChannelMediaOptions options}) → Future<void>
Joins a channel.
joinChannelWithUserAccount({required String token, required String channelId, required String userAccount, ChannelMediaOptions? options}) → Future<void>
Join a channel using a user account and token, and set the media options.
inherited
joinChannelWithUserAccountEx({required String token, required String channelId, required String userAccount, required ChannelMediaOptions options}) → Future<void>
Join a channel using a user account and token, and set the media options.
inherited
leaveChannel({LeaveChannelOptions? options}) → Future<void>
Sets channel options and leaves the channel.
inherited
leaveChannelEx({required RtcConnection connection, LeaveChannelOptions? options}) → Future<void>
Sets channel options and leaves the channel.
loadExtensionProvider({required String path, bool unloadAfterUse = false}) → Future<void>
Loads an extension.
inherited
muteAllRemoteAudioStreams(bool mute) → Future<void>
Stops or resumes subscribing to the audio streams of all remote users.
inherited
muteAllRemoteAudioStreamsEx({required bool mute, required RtcConnection connection}) → Future<void>
Stops or resumes subscribing to the audio streams of all remote users.
muteAllRemoteVideoStreams(bool mute) → Future<void>
Stops or resumes subscribing to the video streams of all remote users.
inherited
muteAllRemoteVideoStreamsEx({required bool mute, required RtcConnection connection}) → Future<void>
Stops or resumes subscribing to the video streams of all remote users.
muteLocalAudioStream(bool mute) → Future<void>
Stops or resumes publishing the local audio stream.
inherited
muteLocalAudioStreamEx({required bool mute, required RtcConnection connection}) → Future<void>
Stops or resumes publishing the local audio stream.
muteLocalVideoStream(bool mute) → Future<void>
Stops or resumes publishing the local video stream.
inherited
muteLocalVideoStreamEx({required bool mute, required RtcConnection connection}) → Future<void>
Stops or resumes publishing the local video stream.
muteRecordingSignal(bool mute) → Future<void>
Whether to mute the recording signal.
inherited
muteRemoteAudioStream({required int uid, required bool mute}) → Future<void>
Stops or resumes subscribing to the audio stream of a specified user.
inherited
muteRemoteAudioStreamEx({required int uid, required bool mute, required RtcConnection connection}) → Future<void>
Stops or resumes receiving the audio stream of a specified user.
muteRemoteVideoStream({required int uid, required bool mute}) → Future<void>
Stops or resumes subscribing to the video stream of a specified user.
inherited
muteRemoteVideoStreamEx({required int uid, required bool mute, required RtcConnection connection}) → Future<void>
Stops or resumes receiving the video stream of a specified user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseAllChannelMediaRelay() → Future<void>
Pauses the media stream relay to all target channels.
inherited
pauseAllChannelMediaRelayEx(RtcConnection connection) → Future<void>
Pauses the media stream relay to all target channels.
pauseAllEffects() → Future<void>
Pauses all audio effects.
inherited
pauseAudioMixing() → Future<void>
Pauses playing and mixing the music file.
inherited
pauseEffect(int soundId) → Future<void>
Pauses a specified audio effect file.
inherited
playAllEffects({required int loopCount, required double pitch, required double pan, required int gain, bool publish = false}) → Future<void>
Plays all audio effect files.
inherited
playEffect({required int soundId, required String filePath, required int loopCount, required double pitch, required double pan, required int gain, bool publish = false, int startPos = 0}) → Future<void>
Plays the specified local or online audio effect file.
inherited
preloadChannel({required String token, required String channelId, required int uid}) → Future<void>
Preloads a channel with token, channelId, and uid.
inherited
preloadChannelWithUserAccount({required String token, required String channelId, required String userAccount}) → Future<void>
Preloads a channel with token, channelId, and userAccount.
inherited
preloadEffect({required int soundId, required String filePath, int startPos = 0}) → Future<void>
Preloads a specified audio effect file into the memory.
inherited
queryCameraFocalLengthCapability() → Future<List<FocalLengthInfo>>
Queries the focal length capability supported by the camera.
inherited
queryCodecCapability(int size) → Future<List<CodecCapInfo>>
Queries the video codec capabilities of the SDK.
inherited
queryDeviceScore() → Future<int>
Queries device score.
inherited
queryScreenCaptureCapability() → Future<int>
Queries the highest frame rate supported by the device during screen sharing.
inherited
rate({required String callId, required int rating, required String description}) → Future<void>
Allows a user to rate a call after the call ends.
inherited
registerAudioEncodedFrameObserver({required AudioEncodedFrameObserverConfig config, required AudioEncodedFrameObserver observer}) → void
Registers an encoded audio observer.
inherited
registerAudioSpectrumObserver(AudioSpectrumObserver observer) → void
Register an audio spectrum observer.
inherited
registerEventHandler(RtcEngineEventHandler eventHandler) → void
Adds event handlers
inherited
registerExtension({required String provider, required String extension, MediaSourceType type = MediaSourceType.unknownMediaSource}) → Future<void>
Registers an extension.
inherited
registerLocalUserAccount({required String appId, required String userAccount}) → Future<void>
Registers a user account.
inherited
registerMediaMetadataObserver({required MetadataObserver observer, required MetadataType type}) → void
Registers the metadata observer.
inherited
release({bool sync = false}) → Future<void>
Releases the RtcEngine instance.
inherited
renewToken(String token) → Future<void>
Renews the token.
inherited
resumeAllChannelMediaRelay() → Future<void>
Resumes the media stream relay to all target channels.
inherited
resumeAllChannelMediaRelayEx(RtcConnection connection) → Future<void>
Resumes the media stream relay to all target channels.
resumeAllEffects() → Future<void>
Resumes playing all audio effect files.
inherited
resumeAudioMixing() → Future<void>
Resumes playing and mixing the music file.
inherited
resumeEffect(int soundId) → Future<void>
Resumes playing a specified audio effect.
inherited
selectAudioTrack(int index) → Future<void>
Selects the audio track used during playback.
inherited
sendCustomReportMessage({required String id, required String category, required String event, required String label, required int value}) → Future<void>
Reports customized messages.
inherited
sendCustomReportMessageEx({required String id, required String category, required String event, required String label, required int value, required RtcConnection connection}) → Future<void>
Agora supports reporting and analyzing customized messages.
sendMetaData({required Metadata metadata, required VideoSourceType sourceType}) → Future<void>
Sends media metadata.
inherited
sendStreamMessage({required int streamId, required Uint8List data, required int length}) → Future<void>
Sends data stream messages.
inherited
sendStreamMessageEx({required int streamId, required Uint8List data, required int length, required RtcConnection connection}) → Future<void>
Sends data stream messages.
setAdvancedAudioOptions({required AdvancedAudioOptions options, int sourceType = 0}) → Future<void>
Sets audio advanced options.
inherited
setAINSMode({required bool enabled, required AudioAinsMode mode}) → Future<void>
Sets whether to enable the AI ​​noise suppression function and set the noise suppression mode.
inherited
setAudioEffectParameters({required AudioEffectPreset preset, required int param1, required int param2}) → Future<void>
Sets parameters for SDK preset audio effects.
inherited
setAudioEffectPreset(AudioEffectPreset preset) → Future<void>
Sets an SDK preset audio effect.
inherited
setAudioMixingDualMonoMode(AudioMixingDualMonoMode mode) → Future<void>
Sets the channel mode of the current audio file.
inherited
setAudioMixingPitch(int pitch) → Future<void>
Sets the pitch of the local music file.
inherited
setAudioMixingPlaybackSpeed(int speed) → Future<void>
Sets the playback speed of the current audio file.
inherited
setAudioMixingPosition(int pos) → Future<void>
Sets the audio mixing position.
inherited
setAudioProfile({required AudioProfileType profile, AudioScenarioType scenario = AudioScenarioType.audioScenarioDefault}) → Future<void>
Sets the audio profile and audio scenario.
inherited
setAudioScenario(AudioScenarioType scenario) → Future<void>
Sets audio scenarios.
inherited
setAudioSessionOperationRestriction(AudioSessionOperationRestriction restriction) → Future<void>
Sets the operational permission of the SDK on the audio session.
inherited
setBeautyEffectOptions({required bool enabled, required BeautyOptions options, MediaSourceType type = MediaSourceType.primaryCameraSource}) → Future<void>
Sets the image enhancement options.
inherited
setCameraAutoExposureFaceModeEnabled(bool enabled) → Future<void>
Sets whether to enable auto exposure.
inherited
setCameraAutoFocusFaceModeEnabled(bool enabled) → Future<void>
Enables the camera auto-face focus function.
inherited
setCameraCapturerConfiguration(CameraCapturerConfiguration config) → Future<void>
Sets the camera capture configuration.
inherited
setCameraDeviceOrientation({required VideoSourceType type, required VideoOrientation orientation}) → Future<void>
Sets the rotation angle of the captured video.
inherited
setCameraExposureFactor(double factor) → Future<void>
Sets the camera exposure value.
inherited
setCameraExposurePosition({required double positionXinView, required double positionYinView}) → Future<void>
Sets the camera exposure position.
inherited
setCameraFocusPositionInPreview({required double positionX, required double positionY}) → Future<void>
Sets the camera manual focus position.
inherited
setCameraStabilizationMode(CameraStabilizationMode mode) → Future<void>
Set the camera stabilization mode.
inherited
setCameraTorchOn(bool isOn) → Future<void>
Enables the camera flash.
inherited
setCameraZoomFactor(double factor) → Future<void>
Sets the camera zoom factor.
inherited
setChannelProfile(ChannelProfileType profile) → Future<void>
Sets the channel profile.
inherited
setClientRole({required ClientRoleType role, ClientRoleOptions? options}) → Future<void>
Set the user role and the audience latency level in a live streaming scenario.
inherited
setCloudProxy(CloudProxyType proxyType) → Future<void>
Sets up cloud proxy service.
inherited
setColorEnhanceOptions({required bool enabled, required ColorEnhanceOptions options, MediaSourceType type = MediaSourceType.primaryCameraSource}) → Future<void>
Sets color enhancement.
inherited
setDefaultAudioRouteToSpeakerphone(bool defaultToSpeaker) → Future<void>
Sets the default audio playback route.
inherited
setDirectCdnStreamingAudioConfiguration(AudioProfileType profile) → Future<void>
Sets the audio profile of the audio streams directly pushed to the CDN by the host.
inherited
setDirectCdnStreamingVideoConfiguration(VideoEncoderConfiguration config) → Future<void>
Sets the video profile of the media streams directly pushed to the CDN by the host.
inherited
setDualStreamMode({required SimulcastStreamMode mode, SimulcastStreamConfig? streamConfig}) → Future<void>
Sets dual-stream mode configuration on the sender side.
inherited
setDualStreamModeEx({required SimulcastStreamMode mode, required SimulcastStreamConfig streamConfig, required RtcConnection connection}) → Future<void>
Sets the dual-stream mode on the sender side.
setEarMonitoringAudioFrameParameters({required int sampleRate, required int channel, required RawAudioFrameOpModeType mode, required int samplesPerCall}) → Future<void>
Sets the format of the in-ear monitoring raw audio data.
inherited
setEffectPosition({required int soundId, required int pos}) → Future<void>
Sets the playback position of an audio effect file.
inherited
setEffectsVolume(int volume) → Future<void>
Sets the volume of the audio effects.
inherited
setEnableSpeakerphone(bool speakerOn) → Future<void>
Enables/Disables the audio route to the speakerphone.
inherited
setExtensionProperty({required String provider, required String extension, required String key, required String value, MediaSourceType type = MediaSourceType.unknownMediaSource}) → Future<void>
Sets the properties of the extension.
inherited
setExtensionProviderProperty({required String provider, required String key, required String value}) → Future<void>
Sets the properties of the extension provider.
inherited
setExternalMediaProjection(int mediaProjection) → Future<void>
Configures MediaProjection outside of the SDK to capture screen video streams.
inherited
setFilterEffectOptions({required bool enabled, required FilterEffectOptions options, MediaSourceType type = MediaSourceType.primaryCameraSource}) → Future<void>
Sets the filter effect options and specifies the media source.
inherited
setHeadphoneEQParameters({required int lowGain, required int highGain}) → Future<void>
Sets the low- and high-frequency parameters of the headphone equalizer.
inherited
setHeadphoneEQPreset(HeadphoneEqualizerPreset preset) → Future<void>
Sets the preset headphone equalization effect.
inherited
setInEarMonitoringVolume(int volume) → Future<void>
Sets the volume of the in-ear monitor.
inherited
setLocalRenderMode({required RenderModeType renderMode, VideoMirrorModeType mirrorMode = VideoMirrorModeType.videoMirrorModeAuto}) → Future<void>
Updates the display mode of the local video view.
inherited
setLocalRenderTargetFps({required VideoSourceType sourceType, required int targetFps}) → Future<void>
Sets the maximum frame rate for rendering local video.
inherited
setLocalVideoMirrorMode(VideoMirrorModeType mirrorMode) → Future<void>
Sets the local video mirror mode.
inherited
setLocalVoiceEqualization({required AudioEqualizationBandFrequency bandFrequency, required int bandGain}) → Future<void>
Sets the local voice equalization effect.
inherited
setLocalVoiceFormant(double formantRatio) → Future<void>
Set the formant ratio to change the timbre of human voice.
inherited
setLocalVoicePitch(double pitch) → Future<void>
Changes the voice pitch of the local speaker.
inherited
setLocalVoiceReverb({required AudioReverbType reverbKey, required int value}) → Future<void>
Sets the local voice reverberation.
inherited
setLogFile(String filePath) → Future<void>
Sets the log file.
inherited
setLogFileSize(int fileSizeInKBytes) → Future<void>
Sets the log file size.
inherited
setLogFilter(LogFilterType filter) → Future<void>
Sets the log output level of the SDK.
inherited
setLogLevel(LogLevel level) → Future<void>
Sets the output log level of the SDK.
inherited
setLowlightEnhanceOptions({required bool enabled, required LowlightEnhanceOptions options, MediaSourceType type = MediaSourceType.primaryCameraSource}) → Future<void>
Sets low-light enhancement.
inherited
setMaxMetadataSize(int size) → Future<void>
Sets the maximum size of the media metadata.
inherited
setMixedAudioFrameParameters({required int sampleRate, required int channel, required int samplesPerCall}) → Future<void>
Set the format of the raw audio data after mixing for audio capture and playback.
inherited
setParameters(String parameters) → Future<void>
Provides technical preview functionalities or special customizations by configuring the SDK with JSON options.
inherited
setPlaybackAudioFrameBeforeMixingParameters({required int sampleRate, required int channel}) → Future<void>
Sets the format of the raw audio playback data before mixing.
inherited
setPlaybackAudioFrameParameters({required int sampleRate, required int channel, required RawAudioFrameOpModeType mode, required int samplesPerCall}) → Future<void>
Sets the format of the raw audio playback data.
inherited
setRecordingAudioFrameParameters({required int sampleRate, required int channel, required RawAudioFrameOpModeType mode, required int samplesPerCall}) → Future<void>
Sets the format of the captured raw audio data.
inherited
setRemoteDefaultVideoStreamType(VideoStreamType streamType) → Future<void>
Sets the default video stream type to subscribe to.
inherited
setRemoteRenderMode({required int uid, required RenderModeType renderMode, required VideoMirrorModeType mirrorMode}) → Future<void>
Updates the display mode of the video view of a remote user.
inherited
setRemoteRenderModeEx({required int uid, required RenderModeType renderMode, required VideoMirrorModeType mirrorMode, required RtcConnection connection}) → Future<void>
Sets the video display mode of a specified remote user.
setRemoteRenderTargetFps(int targetFps) → Future<void>
Sets the maximum frame rate for rendering remote video.
inherited
setRemoteSubscribeFallbackOption(StreamFallbackOptions option) → Future<void>
Sets the fallback option for the subscribed video stream based on the network conditions.
inherited
setRemoteUserSpatialAudioParams({required int uid, required SpatialAudioParams params}) → Future<void>
Sets the spatial audio effect parameters of the remote user.
inherited
setRemoteVideoStreamType({required int uid, required VideoStreamType streamType}) → Future<void>
Sets the video stream type to subscribe to.
inherited
setRemoteVideoStreamTypeEx({required int uid, required VideoStreamType streamType, required RtcConnection connection}) → Future<void>
Sets the video stream type to subscribe to.
setRemoteVideoSubscriptionOptions({required int uid, required VideoSubscriptionOptions options}) → Future<void>
Options for subscribing to remote video streams.
inherited
setRemoteVideoSubscriptionOptionsEx({required int uid, required VideoSubscriptionOptions options, required RtcConnection connection}) → Future<void>
Options for subscribing to remote video streams.
setRemoteVoicePosition({required int uid, required double pan, required double gain}) → Future<void>
Sets the 2D position (the position on the horizontal plane) of the remote user's voice.
inherited
setRemoteVoicePositionEx({required int uid, required double pan, required double gain, required RtcConnection connection}) → Future<void>
Sets the 2D position (the position on the horizontal plane) of the remote user's voice.
setRouteInCommunicationMode(int route) → Future<void>
Selects the audio playback route in communication audio mode.
inherited
setScreenCaptureContentHint(VideoContentHint contentHint) → Future<void>
Sets the content hint for screen sharing.
inherited
setScreenCaptureScenario(ScreenScenarioType screenScenario) → Future<void>
Sets the screen sharing scenario.
inherited
setSubscribeAudioAllowlist({required List<int> uidList, required int uidNumber}) → Future<void>
Sets the allowlist of subscriptions for audio streams.
inherited
setSubscribeAudioAllowlistEx({required List<int> uidList, required int uidNumber, required RtcConnection connection}) → Future<void>
Sets the allowlist of subscriptions for audio streams.
setSubscribeAudioBlocklist({required List<int> uidList, required int uidNumber}) → Future<void>
Set the blocklist of subscriptions for audio streams.
inherited
setSubscribeAudioBlocklistEx({required List<int> uidList, required int uidNumber, required RtcConnection connection}) → Future<void>
Set the blocklist of subscriptions for audio streams.
setSubscribeVideoAllowlist({required List<int> uidList, required int uidNumber}) → Future<void>
Set the allowlist of subscriptions for video streams.
inherited
setSubscribeVideoAllowlistEx({required List<int> uidList, required int uidNumber, required RtcConnection connection}) → Future<void>
Set the allowlist of subscriptions for video streams.
setSubscribeVideoBlocklist({required List<int> uidList, required int uidNumber}) → Future<void>
Set the blocklist of subscriptions for video streams.
inherited
setSubscribeVideoBlocklistEx({required List<int> uidList, required int uidNumber, required RtcConnection connection}) → Future<void>
Set the blocklist of subscriptions for video streams.
setupLocalVideo(VideoCanvas canvas) → Future<void>
Initializes the local video view.
inherited
setupRemoteVideo(VideoCanvas canvas) → Future<void>
Initializes the video view of a remote user.
inherited
setupRemoteVideoEx({required VideoCanvas canvas, required RtcConnection connection}) → Future<void>
Initializes the video view of a remote user.
setVideoDenoiserOptions({required bool enabled, required VideoDenoiserOptions options, MediaSourceType type = MediaSourceType.primaryCameraSource}) → Future<void>
Sets video noise reduction.
inherited
setVideoEncoderConfiguration(VideoEncoderConfiguration config) → Future<void>
Sets the video encoder configuration.
inherited
setVideoEncoderConfigurationEx({required VideoEncoderConfiguration config, required RtcConnection connection}) → Future<void>
Sets the video encoder configuration.
setVideoScenario(VideoApplicationScenarioType scenarioType) → Future<void>
Sets video application scenarios.
inherited
setVoiceBeautifierParameters({required VoiceBeautifierPreset preset, required int param1, required int param2}) → Future<void>
Sets parameters for the preset voice beautifier effects.
inherited
setVoiceBeautifierPreset(VoiceBeautifierPreset preset) → Future<void>
Sets a preset voice beautifier effect.
inherited
setVoiceConversionPreset(VoiceConversionPreset preset) → Future<void>
Sets a preset voice beautifier effect.
inherited
setVolumeOfEffect({required int soundId, required int volume}) → Future<void>
Gets the volume of a specified audio effect file.
inherited
startAudioMixing({required String filePath, required bool loopback, required int cycle, int startPos = 0}) → Future<void>
Starts playing the music file.
inherited
startAudioRecording(AudioRecordingConfiguration config) → Future<void>
Starts audio recording on the client and sets recording configurations.
inherited
startCameraCapture({required VideoSourceType sourceType, required CameraCapturerConfiguration config}) → Future<void>
Starts camera capture.
inherited
startDirectCdnStreaming({required DirectCdnStreamingEventHandler eventHandler, required String publishUrl, required DirectCdnStreamingMediaOptions options}) → Future<void>
Starts pushing media streams to the CDN directly.
inherited
startDumpVideo(int type, String dir) → Future<void>

Available on RtcEngine, provided by the RtcEngineDebug extension

startEchoTest(EchoTestConfiguration config) → Future<void>
Starts an audio device loopback test.
inherited
startLastmileProbeTest(LastmileProbeConfig config) → Future<void>
Starts the last mile network probe test.
inherited
startLocalAudioMixer(LocalAudioMixerConfiguration config) → Future<void>
Starts local audio mixing.
inherited
startLocalVideoTranscoder(LocalTranscoderConfiguration config) → Future<void>
Starts the local video mixing.
inherited
startMediaRenderingTracing() → Future<void>
Enables tracing the video frame rendering process.
inherited
startMediaRenderingTracingEx(RtcConnection connection) → Future<void>
Enables tracing the video frame rendering process.
startOrUpdateChannelMediaRelay(ChannelMediaRelayConfiguration configuration) → Future<void>
Starts relaying media streams across channels or updates channels for media relay.
inherited
startOrUpdateChannelMediaRelayEx({required ChannelMediaRelayConfiguration configuration, required RtcConnection connection}) → Future<void>
Starts relaying media streams across channels or updates channels for media relay.
startPreview({VideoSourceType sourceType = VideoSourceType.videoSourceCameraPrimary}) → Future<void>
Enables the local video preview and specifies the video source for the preview.
inherited
startPreviewWithoutSourceType() → Future<void>
Enables the local video preview.
inherited
startRhythmPlayer({required String sound1, required String sound2, required AgoraRhythmPlayerConfig config}) → Future<void>
Enables the virtual metronome.
inherited
startRtmpStreamWithoutTranscoding(String url) → Future<void>
Starts pushing media streams to a CDN without transcoding.
inherited
startRtmpStreamWithoutTranscodingEx({required String url, required RtcConnection connection}) → Future<void>
Starts pushing media streams to a CDN without transcoding.
startRtmpStreamWithTranscoding({required String url, required LiveTranscoding transcoding}) → Future<void>
Starts Media Push and sets the transcoding configuration.
inherited
startRtmpStreamWithTranscodingEx({required String url, required LiveTranscoding transcoding, required RtcConnection connection}) → Future<void>
Starts Media Push and sets the transcoding configuration.
startScreenCapture(ScreenCaptureParameters2 captureParams) → Future<void>
Starts screen capture.
inherited
startScreenCaptureByDisplayId({required int displayId, required Rectangle regionRect, required ScreenCaptureParameters captureParams}) → Future<void>
Captures the screen by specifying the display ID.
inherited
startScreenCaptureByScreenRect({required Rectangle screenRect, required Rectangle regionRect, required ScreenCaptureParameters captureParams}) → Future<void>
Captures the whole or part of a screen by specifying the screen rect.
inherited
startScreenCaptureBySourceType({required VideoSourceType sourceType, required ScreenCaptureConfiguration config}) → Future<void>
Starts screen capture from the specified video source.
inherited
startScreenCaptureByWindowId({required int windowId, required Rectangle regionRect, required ScreenCaptureParameters captureParams}) → Future<void>
Captures the whole or part of a window by specifying the window ID.
inherited
stopAllEffects() → Future<void>
Stops playing all audio effects.
inherited
stopAudioMixing() → Future<void>
Stops playing the music file.
inherited
stopAudioRecording() → Future<void>
Stops the audio recording on the client.
inherited
stopCameraCapture(VideoSourceType sourceType) → Future<void>
Stops camera capture.
inherited
stopChannelMediaRelay() → Future<void>
Stops the media stream relay. Once the relay stops, the host quits all the target channels.
inherited
stopChannelMediaRelayEx(RtcConnection connection) → Future<void>
Stops the media stream relay. Once the relay stops, the host quits all the target channels.
stopDirectCdnStreaming() → Future<void>
Stops pushing media streams to the CDN directly.
inherited
stopDumpVideo() → Future<void>

Available on RtcEngine, provided by the RtcEngineDebug extension

stopEchoTest() → Future<void>
Stops the audio call test.
inherited
stopEffect(int soundId) → Future<void>
Stops playing a specified audio effect.
inherited
stopLastmileProbeTest() → Future<void>
Stops the last mile network probe test.
inherited
stopLocalAudioMixer() → Future<void>
Stops the local audio mixing.
inherited
stopLocalVideoTranscoder() → Future<void>
Stops the local video mixing.
inherited
stopPreview({VideoSourceType sourceType = VideoSourceType.videoSourceCameraPrimary}) → Future<void>
Stops the local video preview.
inherited
stopRhythmPlayer() → Future<void>
Disables the virtual metronome.
inherited
stopRtmpStream(String url) → Future<void>
Stops pushing media streams to a CDN.
inherited
stopRtmpStreamEx({required String url, required RtcConnection connection}) → Future<void>
Stops pushing media streams to a CDN.
stopScreenCapture() → Future<void>
Stops screen capture.
inherited
stopScreenCaptureBySourceType(VideoSourceType sourceType) → Future<void>
Stops screen capture from the specified video source.
inherited
switchCamera() → Future<void>
Switches between front and rear cameras.
inherited
takeSnapshot({required int uid, required String filePath}) → Future<void>
Takes a snapshot of a video stream.
inherited
takeSnapshotEx({required RtcConnection connection, required int uid, required String filePath}) → Future<void>
Takes a snapshot of a video stream using connection ID.
takeSnapshotWithConfig({required int uid, required SnapshotConfig config}) → Future<void>
Takes a screenshot of the video at the specified observation point.
inherited
takeSnapshotWithConfigEx({required RtcConnection connection, required int uid, required SnapshotConfig config}) → Future<void>
Gets a video screenshot of the specified observation point using the connection ID.
toString() → String
A string representation of this object.
inherited
unloadAllEffects() → Future<void>
Releases a specified preloaded audio effect from the memory.
inherited
unloadEffect(int soundId) → Future<void>
Releases a specified preloaded audio effect from the memory.
inherited
unregisterAudioEncodedFrameObserver(AudioEncodedFrameObserver observer) → void
Unregisters the encoded audio frame observer.
inherited
unregisterAudioSpectrumObserver(AudioSpectrumObserver observer) → void
Unregisters the audio spectrum observer.
inherited
unregisterEventHandler(RtcEngineEventHandler eventHandler) → void
Removes the specified callback events.
inherited
unregisterMediaMetadataObserver({required MetadataObserver observer, required MetadataType type}) → void
Unregisters the specified metadata observer.
inherited
updateChannelMediaOptions(ChannelMediaOptions options) → Future<void>
Updates the channel media options after joining the channel.
inherited
updateChannelMediaOptionsEx({required ChannelMediaOptions options, required RtcConnection connection}) → Future<void>
Updates the channel media options after joining the channel.
updateLocalAudioMixerConfiguration(LocalAudioMixerConfiguration config) → Future<void>
Updates the configurations for mixing audio streams locally.
inherited
updateLocalTranscoderConfiguration(LocalTranscoderConfiguration config) → Future<void>
Updates the local video mixing configuration.
inherited
updatePreloadChannelToken(String token) → Future<void>
Updates the wildcard token for preloading channels.
inherited
updateRtmpTranscoding(LiveTranscoding transcoding) → Future<void>
Updates the transcoding configuration.
inherited
updateRtmpTranscodingEx({required LiveTranscoding transcoding, required RtcConnection connection}) → Future<void>
Updates the transcoding configuration.
updateScreenCapture(ScreenCaptureParameters2 captureParams) → Future<void>
Updates the screen capturing parameters.
inherited
updateScreenCaptureParameters(ScreenCaptureParameters captureParams) → Future<void>
Updates the screen capturing parameters.
inherited
updateScreenCaptureRegion(Rectangle regionRect) → Future<void>
Updates the screen capturing region.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited