VideoDenoiserOptions class

Video noise reduction options.

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode → int
The hash code for this object.
no setterinherited
level → VideoDenoiserLevel?
Video noise reduction level.
final
mode → VideoDenoiserMode?
Video noise reduction mode.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited