WatermarkOptions class

Configurations of the watermark image.

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mode → WatermarkFitMode?
The adaptation mode of the watermark. See WatermarkFitMode.
final
positionInLandscapeMode → Rectangle?
When the adaptation mode of the watermark is fitModeCoverPosition, it is used to set the area of the watermark image in landscape mode. See Rectangle.
final
positionInPortraitMode → Rectangle?
When the adaptation mode of the watermark is fitModeCoverPosition, it is used to set the area of the watermark image in portrait mode. See Rectangle.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visibleInPreview → bool?
Whether the watermark is visible in the local preview view: true : (Default) The watermark is visible in the local preview view. false : The watermark is not visible in the local preview view.
final
watermarkRatio → WatermarkRatio?
When the watermark adaptation mode is fitModeUseImageRatio, this parameter is used to set the watermark coordinates. See WatermarkRatio.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited