registerVideoFrameObserver abstract method
Registers a video frame observer object.
You need to implement the MediaPlayerVideoFrameObserver class in this method and register callbacks according to your scenarios. After you successfully register the video frame observer, the SDK triggers the registered callbacks each time a video frame is received.
observerThe video observer, reporting the reception of each video frame. See MediaPlayerVideoFrameObserver.
Returns When the method call succeeds, there is no return value; when fails, the AgoraRtcException exception is thrown. You need to catch the exception and handle it accordingly.
Implementation
void registerVideoFrameObserver(MediaPlayerVideoFrameObserver observer);